@@ -10,8 +10,6 @@ from typing import List, Dict, Optional
 
 from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, \
     TerraformModuleInput, TerraformModuleComputeService, TerraformModuleOutput, SpaceTerraformModuleInput
-from gateways.common.cs18_api_classes import HelmChartDescriptor, \
-    SpaceHelmChartInput, SpaceHelmChartComputeService, SpaceHelmChartOutput
 from gateways.common.cs18_api_errors import SandboxError, Error
 
 
@@ -112,60 +110,6 @@ class CatalogApplicationResponse:
         self.version = version
 
 
-class CatalogForGetResponse:
-    def __init__(
-            self,
-            name: str,
-            description: str,
-            url: str,
-            last_modified: str,
-            modified_by: str,
-            clouds: List[str],
-            applications: List[CatalogApplicationResponse],
-            links: List[HyperlinkResponse],
-            artifacts: Dict[str, str],
-            errors: [],
-            tags: List[BlueprintTagResponse],
-    ):
-        self.errors = errors
-        self.links = links
-        self.url = url
-        self.description = description
-        self.name = name
-        self.last_modified = last_modified
-        self.modified_by = modified_by
-        self.clouds = clouds
-        self.applications = applications
-        self.artifacts = artifacts
-        self.tags = tags
-
-
-class CatalogForGetAllResponse:
-    def __init__(
-            self,
-            name: str,
-            description: str,
-            url: str,
-            last_modified: str,
-            modified_by: str,
-            clouds: List[str],
-            links: List[HyperlinkResponse],
-            artifacts: Dict[str, str],
-            errors: [],
-            tags: List[BlueprintTagResponse],
-    ):
-        self.links = links
-        self.url = url
-        self.description = description
-        self.name = name
-        self.last_modified = last_modified
-        self.modified_by = modified_by
-        self.clouds = clouds
-        self.artifacts = artifacts
-        self.errors = errors
-        self.tags = tags
-
-
 class BlueprintApplicationResponse:
     def __init__(self, name: str, version: str):
         self.name = name
@@ -276,6 +220,60 @@ class BlueprintResponse:
         self.tags = tags
 
 
+class CatalogForGetResponse:
+    def __init__(
+            self,
+            name: str,
+            description: str,
+            url: str,
+            last_modified: str,
+            modified_by: str,
+            clouds: List[BlueprintCloudResponse],
+            applications: List[CatalogApplicationResponse],
+            links: List[HyperlinkResponse],
+            artifacts: Dict[str, str],
+            errors: [],
+            tags: List[BlueprintTagResponse],
+    ):
+        self.errors = errors
+        self.links = links
+        self.url = url
+        self.description = description
+        self.name = name
+        self.last_modified = last_modified
+        self.modified_by = modified_by
+        self.clouds = clouds
+        self.applications = applications
+        self.artifacts = artifacts
+        self.tags = tags
+
+
+class CatalogForGetAllResponse:
+    def __init__(
+            self,
+            name: str,
+            description: str,
+            url: str,
+            last_modified: str,
+            modified_by: str,
+            clouds: List[BlueprintCloudResponse],
+            links: List[HyperlinkResponse],
+            artifacts: Dict[str, str],
+            errors: [],
+            tags: List[BlueprintTagResponse],
+    ):
+        self.links = links
+        self.url = url
+        self.description = description
+        self.name = name
+        self.last_modified = last_modified
+        self.modified_by = modified_by
+        self.clouds = clouds
+        self.artifacts = artifacts
+        self.errors = errors
+        self.tags = tags
+
+
 class SourceControlDetailsResponse:
     def __init__(
             self,
@@ -508,16 +506,6 @@ class ServiceTfProgressResponse:
         self.tf_destroy_status = tf_destroy_status
 
 
-class ServiceResponse:
-    def __init__(self,
-                 name: str,
-                 service_type: str,
-                 status: str):
-        self.name = name
-        self.type = service_type
-        self.status = status
-
-
 class ServiceTfLogInfo:
     def __init__(self,
                  location: str,
@@ -542,38 +530,16 @@ class ServiceTfLogsResponse:
         self.tf_destroy = tf_destroy
 
 
-class TerraformServiceResponse(ServiceResponse):
+class ServiceResponse:
     def __init__(self,
                  name: str,
                  service_type: str,
                  status: str,
                  progress: ServiceTfProgressResponse,
                  logs: ServiceTfLogsResponse = None):
-        super().__init__(name=name, service_type=service_type, status=status)
-        self.progress = progress
-        self.logs = logs
-
-
-class HelmServiceLogResponse:
-    def __init__(self,
-                 activity_display_name: str,
-                 log_path: str,
-                 start_time: str,
-                 duration: str):
-        self.activity_display_name = activity_display_name
-        self.log_path = log_path
-        self.start_time = start_time
-        self.duration = duration
-
-
-class HelmServiceResponse(ServiceResponse):
-    def __init__(self,
-                 name: str,
-                 service_type: str,
-                 status: str,
-                 progress: Dict[str,str],
-                 logs: Dict[str, HelmServiceLogResponse] = None):
-        super().__init__(name=name, service_type=service_type, status=status)
+        self.name = name
+        self.type = service_type
+        self.status = status
         self.progress = progress
         self.logs = logs
 
@@ -588,7 +554,8 @@ class CustomTagResponse:
                  modified_by: str,
                  last_modified: datetime,
                  created_by: str,
-                 created_date: datetime):
+                 created_date: datetime
+                 ):
         self.name = name
         self.value = value
         self.scope = scope
@@ -1436,32 +1403,3 @@ class SpaceTerraformModuleResponse:
 class BlueprintPolicyResponse:
     def __init__(self, max_duration: timedelta):
         self.max_duration = max_duration
-        
-
-class SpaceHelmChartModuleResponse:
-    def __init__(
-            self,
-            name: str,
-            perform_helm_test: bool,
-            enable_logs: bool,
-            inputs: List[SpaceHelmChartInput],
-            outputs: List[SpaceHelmChartOutput],
-            compute_service: SpaceHelmChartComputeService,
-            chart_root_path: Optional[str],
-            description: Optional[str],
-            override_values_yaml: Optional[str],
-            created_by: str,
-            created_date: datetime,
-            modified_by: str,
-            last_modified: datetime,
-            commands: Optional[List[str]]
-    ):
-        self.chart_descriptor = HelmChartDescriptor(name=name, perform_helm_test=perform_helm_test,
-                                                    enable_logs=enable_logs, inputs=inputs,
-                                                    outputs=outputs, compute_service=compute_service,
-                                                    chart_root_path=chart_root_path, description=description,
-                                                    override_values_yaml=override_values_yaml, commands=commands)
-        self.created_by = created_by
-        self.created_date = created_date
-        self.modified_by = modified_by
-        self.last_modified = last_modified
